@@ -1,4 +1,5 @@
 import matplotlib.pyplot as plt
+import matplotlib.image as mpimg
 import matplotlib
 import StringIO
 
@@ -10,3 +11,8 @@ class Plot:
 		plt.close('all')
 		return(buffer)
 
+class Image:
+	def getImagePath(self, img_obj):
+		buffer = StringIO.StringIO()
+		mpimg.imsave(buffer,img_obj)
+		return(buffer)
